echo "
-------------------------------------------------------------------------------
          METAMLST TEST SCRIPT # 1 - ONE SAMPLE, DEFAULT DATABASE
-------------------------------------------------------------------------------

This test script executes MetaMLST on a single sample using the pre-made
database. 

This test REQUIRES that metamlst folder is in your system path. You have to do
this on your own by typing:

export PATH=<THE_FOLDER_WHERE_METAMLST_IS>/:$PATH;

-------------------------------------------------------------------------------

Input     : A small subset of HMP sample SRS013261, FASTQ format

Database  : Default MetaMLST database. The DB will be downloaded if not already present. Only
			sequences from S. epidermidis will be used (--filter parameter)

Detection : SRS013261: S. epidermidis ST-19

Output    : - Report file:
              - ./out/merged/sepidermidis_report.txt
            - Updated Typing list (STs):
              - ./out/merged/sepidermidis_ST.txt

-------------------------------------------------------------------------------"

#Generate a Bowtie2 index
echo "
-------------------------------------------------------------------------------
Executing: metamlst-index.py -i bowtie_MetaMLST --filter sepidermidis
This builds a new bowtie2 Database called bowtie_MetaMLST from the default
MetaMLST database
-------------------------------------------------------------------------------
"

metamlst-index.py -i bowtie_MetaMLST --filter sepidermidis

#Map the fastq with Bowtie
echo "
-------------------------------------------------------------------------------
Executing: bowtie2 --threads 4 --very-sensitive-local -a --no-unal -x bowtie_MetaMLST -U SRS013261_epidermidis.fastq | samtools view -bS - > SRS013261_epidermidis.bam;
-------------------------------------------------------------------------------
"

bowtie2 --threads 4 --very-sensitive-local -a --no-unal -x bowtie_MetaMLST -U SRS013261_epidermidis.fastq | samtools view -bS - > SRS013261_epidermidis.bam;

#Run MetaMLST on a single sample
echo "
-------------------------------------------------------------------------------
Executing: metamlst.py -d SRS013261_epidermidis.bam -o ./out/
-------------------------------------------------------------------------------
"

metamlst.py SRS013261_epidermidis.bam -o ./out/ --filter sepidermidis

#Type the STs
echo "
-------------------------------------------------------------------------------
Executing: metamlst-merge.py ./out
-------------------------------------------------------------------------------
"

metamlst-merge.py ./out

