echo "
-------------------------------------------------------------------------------
          METAMLST TEST SCRIPT # 3 - ONE SAMPLE, MULTIPLE SPECIES
-------------------------------------------------------------------------------

This test script executes MetaMLST on a single sample, using the pre-made
database, and detects the two species present.

This test REQUIRES that metamlst folder is in your system path. You have to do
this on your own by typing:

export PATH=<THE_FOLDER_WHERE_METAMLST_IS>/:$PATH;
-------------------------------------------------------------------------------

Input     : A small subset of HMP sample SRS013261, FASTQ format

Database  : Default MetaMLST database. The DB will be downloaded if not already present.

Detection : SRS013261: S. epidermidis ST-19
                       P. acnes ST-4
Output    : - Report files:
              - ./out/merged/sepidermidis_report.txt
              - ./out/merged/pacnes_report.txt

            - Updated Typing lists (STs):
              - ./out/merged/sepidermidis_ST.txt
              - ./out/merged/pacnes_ST.txt

-------------------------------------------------------------------------------"

#Generate a Bowtie2 index
echo "
-------------------------------------------------------------------------------
Executing: metamlst-index.py -i bowtie_MetaMLST
-------------------------------------------------------------------------------
"

metamlst-index.py -i bowtie_MetaMLST

echo "
-------------------------------------------------------------------------------
Executing: bowtie2 --threads 4 --very-sensitive-local -a --no-unal -x bowtie_MetaMLST -U SRS013261_epidermidis.fastq | samtools view -bS - > SRS013261_epidermidis.bam;
-------------------------------------------------------------------------------
"

#Map the fastq with Bowtie
bowtie2 --threads 4 --very-sensitive-local -a --no-unal -x bowtie_MetaMLST -U SRS013261_epidermidis.fastq | samtools view -bS - > SRS013261_epidermidis.bam;

echo "
-------------------------------------------------------------------------------
Executing: metamlst.py SRS013261_epidermidis.bam -o ./out/
-------------------------------------------------------------------------------
"

#Run MetaMLST on a single sample
metamlst.py SRS013261_epidermidis.bam -o ./out/

echo "
-------------------------------------------------------------------------------
Executing: metamlst-merge.py ./out
-------------------------------------------------------------------------------
"

#Type the STs
metamlst-merge.py ./out
