echo "
-------------------------------------------------------------------------------
          METAMLST TEST SCRIPT # 4 - TWO SAMPLES
-------------------------------------------------------------------------------

This test script executes MetaMLST on two sample, using the pre-made
database, and detects the two species present.

This test REQUIRES that metamlst folder is in your system path. You have to do
this on your own by typing:

export PATH=<THE_FOLDER_WHERE_METAMLST_IS>/:$PATH;
-------------------------------------------------------------------------------

Input    : A small subset of HMP sample SRS013261, FASTQ format
           A small subset of HMP sample SRS015937, FASTQ format
           A metadata-file: test_metadata.txt, tab-separated format

Database : Default database


Detection : SRS013261: S. epidermidis ST-19
                       P. acnes ST-4

            SRS015937: S. epidermidis ST-100001 (New ST)

Output    : - Report files:
              - ./out/merged/sepidermidis_report.txt
              - ./out/merged/pacnes_report.txt

            - Updated Typing lists (STs):
              - ./out/merged/sepidermidis_ST.txt
              - ./out/merged/pacnes_ST.txt

-------------------------------------------------------------------------------"

#Generate a Bowtie2 index
echo "
-------------------------------------------------------------------------------
Executing: metamlst-index.py -i bowtie_MmetaMLST
-------------------------------------------------------------------------------
"
metamlst-index.py -i bowtie_MetaMLST

#Map the fastq with Bowtie
echo "
-------------------------------------------------------------------------------
Executing: bowtie2 --threads 4 --very-sensitive-local -a --no-unal -x bowtie_MetaMLST -U SRS015937_epidermidis.fastq | samtools view -bS - > SRS015937_epidermidis.bam
-------------------------------------------------------------------------------
"

bowtie2 --threads 4 --very-sensitive-local -a --no-unal -x bowtie_MetaMLST -U SRS015937_epidermidis.fastq | samtools view -bS - > SRS015937_epidermidis.bam;

echo "
-------------------------------------------------------------------------------
Executing: bowtie2 --threads 4 --very-sensitive-local -a --no-unal -x bowtie_MetaMLST -U SRS013261_epidermidis.fastq | samtools view -bS - > SRS013261_epidermidis.bam
-------------------------------------------------------------------------------
"

bowtie2 --threads 4 --very-sensitive-local -a --no-unal -x bowtie_MetaMLST -U SRS013261_epidermidis.fastq | samtools view -bS - > SRS013261_epidermidis.bam;

#Run MetaMLST on a the two samples
echo "
-------------------------------------------------------------------------------
Executing: metamlst.py -d sepidermidis.db SRS015937_epidermidis.bam -o ./out/
-------------------------------------------------------------------------------
"
metamlst.py SRS015937_epidermidis.bam -o ./out/

echo "
-------------------------------------------------------------------------------
Executing: metamlst.py -d sepidermidis.db SRS013261_epidermidis.bam -o ./out/
-------------------------------------------------------------------------------
"

metamlst.py SRS013261_epidermidis.bam -o ./out/

#Type the STs
echo "
-------------------------------------------------------------------------------
Executing: metamlst-merge.py -d sepidermidis.db ./out
-------------------------------------------------------------------------------
"
metamlst-merge.py ./out

