echo "
-------------------------------------------------------------------------------
          METAMLST TEST SCRIPT # 5 - MANY SAMPLES (Phylogenetic Analysis)
-------------------------------------------------------------------------------

This test script executes MetaMLST on 27 samples, using the pre-made
database. The script detects P. acnes and reports files suitable for 
Phylogenetic Analysis (trees and Minimum Spanning Trees)

This test REQUIRES that metamlst folder is in your system path. You have to do
this on your own by typing:

export PATH=<THE_FOLDER_WHERE_METAMLST_IS>/:$PATH;
-------------------------------------------------------------------------------

Input     : 27 files from the HMP (filtered reads matching to P. acnes)

Database  : Default database

Detection : 14 known STs, 13 new STs (ID >100000)

Output    : - Report file: ./out/merged/pacnes_report.txt
            - ST file: ./out/merged/pacnes_ST.txt 
            - Sequences file: ./out/merged/pacnes_sequences.txt

-------------------------------------------------------------------------------"

#Unzipping the archive
unzip 5_phylogenetic_analysis_files.zip

#Generate a Bowtie2 index
echo "
-------------------------------------------------------------------------------
Executing: metamlst-index.py -i bowtie_MetaMLST metamlstDB_2017.db
-------------------------------------------------------------------------------
"
metamlst-index.py -i bowtie_MetaMLST

for i in ./*.fastq; do
   
  bs=$(basename $i)
  echo "
-------------------------------------------------------------------------------
Executing: bowtie2 --threads 4 --very-sensitive-local -a --no-unal -x bowtie_MetaMLST -U "$i" | samtools view -bS - > "${bs%%.*}".bam;
-------------------------------------------------------------------------------
" 
  #Map the fastq with Bowtie
  bowtie2 --threads 4 --very-sensitive-local -a --no-unal -x bowtie_MetaMLST -U $i | samtools view -bS - > ${bs%%.*}.bam;
  
  echo "
-------------------------------------------------------------------------------
Executing: metamlst.py "${bs%%.*}".bam --filter pacnes -o ./out/
-------------------------------------------------------------------------------
" 
  #Run MetaMLST
  metamlst.py ${bs%%.*}.bam --filter pacnes -o ./out/
done


#Type the STs
echo "
-------------------------------------------------------------------------------
Executing: metamlst-merge.py --meta test_metadata.txt ./out
-------------------------------------------------------------------------------
"
metamlst-merge.py --meta sample_metadata.txt --outseqformat A ./out


#Build a Phylogenetic Tree
echo "
-------------------------------------------------------------------------------
Executing: raxmlHPC -m GTRGAMMA -s out/merged/pacnes_sequences.fna -n pacnes_tree -p 1234
-------------------------------------------------------------------------------
"
raxmlHPC -m GTRGAMMA -s out/merged/pacnes_sequences.fna -n pacnes_tree -p 1234