echo "
-------------------------------------------------------------------------------
          METAMLST TEST SCRIPT # 6 - ONE SAMPLE WITH DATABASE UPDATE
-------------------------------------------------------------------------------

This test script executes MetaMLST on a sample harboring a NEW ST (ID > 100000)

Then, MetaMLST-index is run on the resulting updated STs table and sequences 
file to build a custom database including the new type detected (ST 100001).

The pipeline is then run again on the same sample, but with the custom database
and the sample's S. epidermidis, previously detected as new, is now marked as
known (i.e. previously encountered). 

This test REQUIRES that metamlst folder is in your system path. You have to do
this on your own by typing:

export PATH=<THE_FOLDER_WHERE_METAMLST_IS>/:$PATH;

-------------------------------------------------------------------------------

Input     : A small subset of HMP sample SRS015937, FASTQ format
            A metadata-file: test_metadata.txt, tab-separated format

Database  : Default Database


Detection : SRS015937: S. epidermidis ST-100001 (New ST, first pass)
            SRS015937: S. epidermidis ST-100001 (Known ST, second pass)

Output    : - Report files (first pass):
              - ./out/merged/sepidermidis_report.txt

            - Updated Typing lists (STs):
              - ./out/merged/sepidermidis_ST.txt

            - Sequences file (contains the loci-sequences):
              - ./out/merged/sepidermidis_sequences.fna

            - Report files (second pass):
              - ./NEW_out/merged/sepidermidis_report.txt

            - Updated Typing lists (STs):
              - ./NEW_out/merged/sepidermidis_ST.txt
-------------------------------------------------------------------------------"

#Generate a Bowtie2 index
echo "
-------------------------------------------------------------------------------
Executing: metamlst-index.py -i bowtie_MetaMLST
-------------------------------------------------------------------------------
"
metamlst-index.py -i bowtie_MetaMLST

#Map the fastq with Bowtie
echo "
-------------------------------------------------------------------------------
Executing: bowtie2 --threads 4 --very-sensitive-local -a --no-unal -x bowtie_MetaMLST -U SRS015937_epidermidis.fastq | samtools view -bS - > SRS015937_epidermidis.bam
-------------------------------------------------------------------------------
"

bowtie2 --threads 4 --very-sensitive-local -a --no-unal -x bowtie_MetaMLST -U SRS015937_epidermidis.fastq | samtools view -bS - > SRS015937_epidermidis.bam;

#Run MetaMLST on a single sample
echo "
-------------------------------------------------------------------------------
Executing: metamlst.py SRS015937_epidermidis.bam -o ./out/
-------------------------------------------------------------------------------
"
metamlst.py SRS015937_epidermidis.bam -o ./out/

#Type the STs
echo "
-------------------------------------------------------------------------------
Executing: metamlst-merge.py --outseqformat B+ ./out
-------------------------------------------------------------------------------
"
metamlst-merge.py --outseqformat B+ ./out
 

echo "
-------------------------------------------------------------------------------
Now we prepare a custom profiles file with the new discovered STs:

Executing: metamlst-index.py-s out/sepidermidis_sequences.fna -t out/sepidermidis_ST.txt new_metamlstDB.db
-------------------------------------------------------------------------------
"
echo "#sepidermidis|Staphylococcus epidermidis" > out/merged/update_sepidermidis_ST.txt
cat out/merged/sepidermidis_ST.txt >> out/merged/update_sepidermidis_ST.txt
metamlst-index.py -s out/merged/sepidermidis_sequences.fna -t out/merged/update_sepidermidis_ST.txt -d new_metamlstDB.db

echo "
-------------------------------------------------------------------------------
Now we update the custom MetaMLST database with the newly discovered sequecnes

Executing: metamlst-index.py -i new_bowtie_MetaMLST -d new_metamlstDB.db
-------------------------------------------------------------------------------
"
metamlst-index.py -i new_bowtie_MetaMLST -d new_metamlstDB.db

echo "
-------------------------------------------------------------------------------
Now we re-map everything against the new DB

Executing: bowtie2 --threads 4 --very-sensitive-local -a --no-unal -x new_bowtie_MetaMLST -U SRS015937_epidermidis.fastq | samtools view -bS - > SRS015937_epidermidis.bam;
-------------------------------------------------------------------------------
"
bowtie2 --threads 4 --very-sensitive-local -a --no-unal -x new_bowtie_MetaMLST -U SRS015937_epidermidis.fastq | samtools view -bS - > SRS015937_epidermidis.bam;

echo "
-------------------------------------------------------------------------------
MetaMLST profiling

Executing: metamlst.py -d new_metamlstDB.db SRS015937_epidermidis.bam -o ./NEW_out/
-------------------------------------------------------------------------------
"
metamlst.py -d new_metamlstDB.db SRS015937_epidermidis.bam -o ./NEW_out/

echo "
-------------------------------------------------------------------------------
Now the new samples are readily detected as 'known':

Executing: metamlst-merge.py -d new_metamlstDB.db ./NEW_out
-------------------------------------------------------------------------------
"
metamlst-merge.py -d new_metamlstDB.db ./NEW_out